require_dependency "rechn_mgm_user_area/application_controller"

module RechnMgmUserArea
    class OrganisationsController < AuthenticatedController
        before_action :set_user, only: [:resend_invitation]

        def new_invitation
            respond_to do |format|
                format.html
                format.js
            end
        end

        def create_invitation
            invited_user = DeviseAuthentication::User.where(email: organisation_params[:email]).first

            if invited_user.present?
                if invited_user.id == current_user.id
                    flash[:error] = I18n.t "You cannot add yourself!"
                    redirect_to user_root_path
                    return
                end

                if current_user.user_ids_of_current_organisation.include? invited_user.id
                    flash[:error] = I18n.t "This user is already in your organisation!"
                    redirect_to user_root_path
                    return
                end

                if current_user.invited_by_me.map{|u| u.id}.include? invited_user.id
                    flash[:error] = I18n.t "You already invited this user!"
                    redirect_to user_root_path
                    return
                end

                # User is already known: Add him directly
                success = current_user.add_user_to_my_organisation(invited_user.id)
                if success
                    flash[:info] = I18n.t "The invited user was added"
                else
                    flash[:error] = I18n.t "The invited user could not be added. Please contact administrator!"
                end
            else
                # User is not known: Invite him
                flash[:info] = I18n.t("invitation_sent", email: organisation_params[:email])
                DeviseAuthentication::User.invite!({email: organisation_params[:email], forename: organisation_params[:first_name], lastname: organisation_params[:last_name]}, current_user)
            end
            redirect_to user_root_path
        end

        def resend_invitation
            flash[:info] = I18n.t("invitation_sent", email: @user.email)
            DeviseAuthentication::User.invite!({email: @user.email, forename: @user.forename, lastname: @user.lastname}, current_user)

            redirect_to user_root_path
        end


        private
        def organisation_params
            params.require(:invitation).permit(:email, :first_name, :last_name)
        end

        def set_user
            @user = DeviseAuthentication::User.find(params[:user_id])
        end
    end
end
